==> jaysonic-3.1.1.tgz: package/lib/server/tcp.js <==
"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

var net = require("net");

var JsonRpcServerFactory = require(".");

var TCPServerProtocol = require("./protocol/tcp");
/**
 * Creates an instance of TcpServerFactory
 * @extends JsonRpcServerFactory
 */


var TcpServerFactory = /*#__PURE__*/function (_JsonRpcServerFactory) {
  _inherits(TcpServerFactory, _JsonRpcServerFactory);

  var _super = _createSuper(TcpServerFactory);

  function TcpServerFactory() {
    _classCallCheck(this, TcpServerFactory);

    return _super.apply(this, arguments);
  }

  _createClass(TcpServerFactory, [{
    key: "setServer",

    /** @inheritdoc */
    value: function setServer() {
      this.server = new net.Server();
    }
    /** @inheritdoc */

  }, {
    key: "buildProtocol",
    value: function buildProtocol() {
      var _this = this;

      this.server.on("connection", function (client) {
        _this.connectedClients.push(client);

        _this.emit("clientConnected", client);

        _this.pcolInstance = new TCPServerProtocol(_this, client, _this.options.version, _this.options.delimiter);

        _this.pcolInstance.clientConnected();
      });
    }
  }]);

  return TcpServerFactory;
}(JsonRpcServerFactory);

module.exports = TcpServerFactory;

==> jaysonic-3.5.1.tgz: package/lib/server/tcp.js <==
"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

var net = require("net");

var JsonRpcServerFactory = require(".");

var TCPServerProtocol = require("./protocol/tcp");
/**
 * Creates an instance of TcpServerFactory
 * @extends JsonRpcServerFactory
 */


var TcpServerFactory = /*#__PURE__*/function (_JsonRpcServerFactory) {
  _inherits(TcpServerFactory, _JsonRpcServerFactory);

  var _super = _createSuper(TcpServerFactory);

  function TcpServerFactory(options) {
    var _this;

    _classCallCheck(this, TcpServerFactory);

    _this = _super.call(this, options);
    _this.protocol = TCPServerProtocol;
    return _this;
  }
  /** @inheritdoc */


  _createClass(TcpServerFactory, [{
    key: "setServer",
    value: function setServer() {
      this.server = new net.Server();
    }
    /** @inheritdoc */

  }, {
    key: "buildProtocol",
    value: function buildProtocol() {
      var _this2 = this;

      this.server.on("connection", function (client) {
        var pcol = new _this2.protocol(_this2, client, _this2.options.version, _this2.options.delimiter);
        pcol.clientConnected();

        _this2.clients.push(pcol);

        _this2.clientConnected(pcol);

        client.on("end", function () {
          _this2.clientDisconnected(pcol);
        });
      });
    }
  }]);

  return TcpServerFactory;
}(JsonRpcServerFactory);

module.exports = TcpServerFactory;
